/*
 * Copyright (c) 2003 by Diamond Systems Corporation. All Rights Reserved.
 * Use of this source code is subject to the terms of Diamond Systems 
 * Software License Agreement.
 *
 * DALI C/C++ Client demo program
 * See the DALI user manual for information on this API
 *
 * DALI client software must be installed on your system or this program
 * will not compile.  By default it will connect to a DALI server running
 * on your system.  Edit the env.service parameter below to talk to a
 * DALI server on a remote system.
 */

#include <stdio.h>
#include <stdlib.h>
#include "dalic.h"

int main(int argc, char *argv[])
{
	DALIENV env; // DALI client handle
	DALIADSETTINGS adsettings; // AD range/gain/polarity settings
	int lowchannel, highchannel; // Channels to sample
	int *samples; // Holds the data
	int result; // Holds the error code
	int i;

	/* Initialize the client.  Always call this first */
	DALIInit(&env);

	/* Service URL for the DALI server.  Switch to "https" for SSL
	 * encryption.  Change IP to talk to a different server */
	env.service = "http://127.0.0.1:8444/dali/soap/demo";

	lowchannel = 0;
	highchannel = 1;
	adsettings.range = 10; // 10V operation
	adsettings.gain = 2; // AD gain 2
	adsettings.polarity = DALI_UNIPOLAR;

	samples = malloc(sizeof(int) * (highchannel - lowchannel + 1));
	if ( samples == NULL )
		return 1;

	result = DALIADScan(&env, lowchannel, highchannel, &adsettings, samples);
	if ( result )
		printf("DALI error: %s (%d)\n", env.last_error, result);
	else
		for ( i = 0; i < (highchannel-lowchannel+1); i++ )
			printf("DALI CH %2d : %6d\n", lowchannel+i, samples[i]);

	free(samples);

	/* Closes any network connections and frees memory associated
	 * with the client handle */
	DALIFree(&env);
	return 0;
}

