/*
 * Copyright (c) 2003 by Diamond Systems Corporation. All Rights Reserved.
 * Use of this source code is subject to the terms of Diamond Systems 
 * Software License Agreement.
 *
 * DALI C/C++ Client demo program
 * See the DALI user manual for information on this API
 *
 * DALI client software must be installed on your system or this program
 * will not compile.  By default it will connect to a DALI server running
 * on your system.  Edit the env.service parameter below to talk to a
 * DALI server on a remote system.
 */

#include <stdio.h>
#include <string.h>
#include "dalic.h"

#define BUFSIZE 128

int main(int argc, char *argv[])
{
	DALIENV env; // DALI client handle
	DALIADSETTINGS adsettings; // AD range/gain/polarity settings
	DALIALARMSETTINGS alarmsettings; // Alarm configuration
	int channel; // Channel to monitor
	int lowvalue, highvalue; // Range of acceptable AD code values
	int result; // Holds the error code
	char alarmid[BUFSIZE];

	/* Initialize the client.  Always call this first */
	DALIInit(&env);

	/* Service URL for the DALI server.  Switch to "https" for SSL
	 * encryption.  Change IP to talk to a different server */
	env.service = "http://127.0.0.1:8444/dali/soap/demo";

	channel = 0; // Channel 0
	lowvalue = 0; // Alarm signals if AD code below this value
	highvalue = 100; // Alarm signals if AD code above this value

	adsettings.range = 5; // 5V operation
	adsettings.gain = 1; // AD gain 1
	adsettings.polarity = DALI_BIPOLAR;

	alarmsettings.period = 10; // Check once every 10 seconds
	alarmsettings.duration = 300; // Stop watching after 5 minutes
	/* Wait one minute before notifying again */
	alarmsettings.postalarmpause = 60;
	strcpy(alarmsettings.actiontype, "EMAIL"); // Send e-mail for alarm
	strcpy(alarmsettings.actiontarget, "you@example"); // To this address

	result = DALIAlarmADOutOfRange(&env, channel, lowvalue, highvalue, 
					&adsettings, &alarmsettings, alarmid, BUFSIZE);
	if ( result )
		printf("DALI error: %s (%d)\n", env.last_error, result);
	else
		printf("DALI: Alarm ID: %s\n", alarmid);

	/* Closes any network connections and frees memory associated
	 * with the client handle */
	DALIFree(&env);
	return 0;
}

